@@ -4,8 +4,10 @@ import logging
 import re
 
 from django.contrib.admindocs.views import simplify_regex
+from django.core.exceptions import ObjectDoesNotExist
 from django.urls import URLResolver, URLPattern
 from django.urls.resolvers import RegexPattern
+from django_celery_beat.models import CrontabSchedule, PeriodicTask
 from mongoengine.errors import ValidationError
 
 import core_exporters_app.components.exporter.api as exporters_api
@@ -13,6 +15,7 @@ import core_main_app.commons.exceptions as main_exception
 import core_main_app.system.api as system_api
 from core_exporters_app.components.exporter.models import Exporter
 from core_exporters_app.exporters import urls
+from core_exporters_app.tasks import delete_old_exported_files
 
 logger = logging.getLogger(__name__)
 
@@ -115,3 +118,18 @@ def discover_exporter():
         )
     except Exception as e:
         raise e
+
+
+def init_periodic_tasks():
+    """Create periodic tasks for the app and add them to a crontab schedule"""
+    schedule, _ = CrontabSchedule.objects.get_or_create(
+        minute="*",
+    )
+    try:
+        PeriodicTask.objects.get(name=delete_old_exported_files.__name__)
+    except ObjectDoesNotExist:
+        PeriodicTask.objects.create(
+            crontab=schedule,
+            name=delete_old_exported_files.__name__,
+            task="core_exporters_app.tasks.delete_old_exported_files",
+        )
